/*
 * Copyright 2002-2007 Sun Microsystems, Inc.  All Rights Reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
 * CA 95054 USA or visit www.sun.com if you need additional information or
 * have any questions.
 */
package org.jdesktop.swingx.designer.jibxhelpers;

import org.jibx.runtime.IMarshaller;
import org.jibx.runtime.IMarshallingContext;
import org.jibx.runtime.IUnmarshaller;
import org.jibx.runtime.IUnmarshallingContext;
import org.jibx.runtime.JiBXException;
import org.jibx.runtime.impl.MarshallingContext;
import org.jibx.runtime.impl.UnmarshallingContext;

import java.awt.Color;

/**
 * ColorMapper
 *
 * @author Created by Jasper Potts (Jun 8, 2007)
 */
public class ColorMapper implements IMarshaller, IUnmarshaller {
    private static final String ELEMENT_NAME = "color";
    private static final String RED_NAME = "red";
    private static final String GREEN_NAME = "green";
    private static final String BLUE_NAME = "blue";
    private static final String ALPHA_NAME = "alpha";

    public boolean isExtension(int i) {
        return false;
    }

    public boolean isPresent(IUnmarshallingContext iUnmarshallingContext) throws JiBXException {
        return iUnmarshallingContext.isAt(null, ELEMENT_NAME);
    }

    public void marshal(Object object, IMarshallingContext iMarshallingContext) throws JiBXException {
        if (!(object instanceof Color)) {
            throw new JiBXException("Invalid object type for marshaller");
        } else if (!(iMarshallingContext instanceof MarshallingContext)) {
            throw new JiBXException("Invalid object type for marshaller");
        } else {
            MarshallingContext ctx = (MarshallingContext) iMarshallingContext;
            Color color = (Color) object;
            ctx.startTagAttributes(0, ELEMENT_NAME).
                    attribute(0, RED_NAME, color.getRed()).
                    attribute(0, GREEN_NAME, color.getGreen()).
                    attribute(0, BLUE_NAME, color.getBlue()).
                    attribute(0, ALPHA_NAME, color.getAlpha()).
                    closeStartEmpty();
        }
    }

    public Object unmarshal(Object object, IUnmarshallingContext iUnmarshallingContext) throws JiBXException {
        // make sure we're at the appropriate start tag
        UnmarshallingContext ctx = (UnmarshallingContext) iUnmarshallingContext;
        if (!ctx.isAt(null, ELEMENT_NAME)) {
            ctx.throwStartTagNameError(null, ELEMENT_NAME);
        }
        // get values
        int red = ctx.attributeInt(null, RED_NAME, 0);
        int green = ctx.attributeInt(null, GREEN_NAME, 0);
        int blue = ctx.attributeInt(null, BLUE_NAME, 0);
        int alpha = ctx.attributeInt(null, ALPHA_NAME, 0);
        ctx.parsePastEndTag(null, ELEMENT_NAME);
        // create
        return new Color(red, green, blue, alpha);
    }
}
